@@ -370,7 +370,6 @@ def identify_tit_sites(f_in, chains, nomenclature="PDB", add_ser_thr=False):
         return chain_res
 
     chain_res = {chain: {} for chain in chains}
-    skip_NTR = {chain: False for chain in chains}
     last_res = None
     with open(f_in) as f:
         content = f.readlines()
@@ -403,12 +402,9 @@ def identify_tit_sites(f_in, chains, nomenclature="PDB", add_ser_thr=False):
                     if resnumb not in chain_sites:
                         if (
                             not chain_res[chain]
-                            and not skip_NTR[chain]
+                            and resname != "PRO"
                             and aname in ("H1", "H2", "H3", "N")
-                        ):
-                            if resname == "PRO":
-                                skip_NTR[chain] = True
-                                continue
+                        ) or (aname in ("H1", "H2", "H3")):
                             chain_res = add_site(chain_res, chain, resnumb, "NTR")
 
                         if (
